RemoteServer

Struct RemoteServer 

pub struct RemoteServer<L: AsyncLink, F: Fn() -> L> { /* private fields */ }
Available on crate feature server only.
A server that accepts connections from Remote clients and forwards requests to a link.

Implementations

Source

impl<L: AsyncLink, F: Fn() -> L> RemoteServer<L, F>

pub const fn new(port: u16, link_factory: F) -> Self

Create a new RemoteServer.

Arguments
  • port - The port to listen on
  • link - A factory function that creates a new link instance
pub fn with_graceful_shutdown<S>(self, signal: S) -> Self
where S: Future<Output = ()> + Send + 'static,

Configure graceful shutdown with a custom shutdown signal.

Arguments
  • signal - A future that completes when the server should shut down
pub async fn run(&mut self) -> Result<(), LinkError>

Run the server.

This method listens for incoming connections asynchronously. For each connection, it processes requests and forwards them to the link.

If a shutdown signal is configured via with_graceful_shutdown, the server will gracefully shut down when the signal completes.

Errors

Returns an error if:

  • Failed to bind to the specified port
  • Failed to accept a connection
  • Failed to process a request